"use strict";
function init(modules) {
    const ts = modules.typescript;
    function create(info) {
        // Get a list of things to remove from the completion list from the config object.
        // If nothing was specified, we'll just remove 'caller'
        const whatToRemove = info.config.remove || [];
        const whatToInclude = info.config.include || [];
        const logger = info.project.projectService.logger;
        // Diagnostic logging
        logger.info("I'm getting set up now! Check the log for this message.");
        // Set up decorator object
        const proxy = Object.create(null);
        for (let k of Object.keys(info.languageService)) {
            const x = info.languageService[k];
            // @ts-expect-error - JS runtime trickery which is tricky to type tersely
            proxy[k] = (...args) => x.apply(info.languageService, args);
        }
        // Remove specified entries from completion list
        proxy.getCompletionsAtPosition = (fileName, position, options) => {
            // This is just to let you hook into something to
            // see the debugger working
            // debugger        
            const prior = info.languageService.getCompletionsAtPosition(fileName, position, options);
            if (!prior) {
                return;
            }
            const oldLength = prior.entries.length;
            let i = 0;
            prior.entries.forEach(e => {
                logger.info(`Completion entry ${i}: ${JSON.stringify(e)}`);
                i += 1;
            });
            prior.entries = prior.entries
                .filter(e => (whatToRemove.indexOf(e.name) === -1))
                .filter(e => (e.kind !== 'directory' && e.kind !== 'external module name') || (whatToInclude.length === 0) || (whatToInclude.indexOf(e.name) >= 0));
            // Sample logging for diagnostic purposes
            if (oldLength !== prior.entries.length) {
                const entriesRemoved = oldLength - prior.entries.length;
                logger.info(`Removed ${entriesRemoved} entries from the completion list`);
            }
            return prior;
        };
        return proxy;
    }
    return { create };
}
module.exports = init;
//# sourceMappingURL=index.js.map